# ERU: One Framework for all

![Eru logo](https://s3.amazonaws.com/aws-website-shawnshancom-tm5f7/eru.png)

## You have just found ERU.

High Level Framework for PyTorch

Currently the Framework is under active developing and the first version is ready. 

Eru is designed to help with Deep Learning researchers to try out advanced models efficiently, so we recommend users to have some understanding of deep learning before using. For this reason, Eru is only implement on GPUs, but we will build CPU configuration soon. 

Any help and suggestions with the code will be greatly appreciated. Contect me at shansixioing@uchicago.edu

## Quick Start
Comming Soon

We are writing a detailed version of the documentation and tutorial...

## Examples
We have several illustrative examples ranging from basic MLP to sentiment classifiers in the [example folder](https://github.com/Shawn-Shan/Eru/tree/master/examples)

## Installation

Before installing Eru, please install Pytorch following the instruction on http://pytorch.org/

- **Install Eru from PyPI (recommended):**

```sh
sudo pip3 install Eru
```
